@@ -1,6 +1,6 @@
 /*  double/dbmount.c	mount device/file on DouBle device  1 Jan 1994
  *
- *  Copyright (C) 1994 Jean-Marc Verbavatz  <jmv@receptor.mgh.harvard.edu>
+ *  Copyright (C) 1994 Jean-Marc Verbavatz  <verbavatz@dsvidf.cea.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,17 +27,17 @@ main(argc, argv)
 int argc;
 char **argv;
 {
-int fp, gp;
+int fd, gd;
 
-if(argc != 3 || (fp = open(argv[1], O_RDWR))<0
-		|| (gp = open(argv[2], O_RDWR)) < 0) {
+if(argc != 3 || (fd = open(argv[1], O_RDWR))<0
+		|| (gd = open(argv[2], O_RDWR)) < 0) {
 	if(errno) perror(argv[0]);
 	usage(argv[0]);
 }
-if(ioctl(gp, DBLE_SET_FD, fp))
+if(ioctl(gd, DBLE_SET_FD, fd))
 	if(errno) perror(argv[0]);
-close(gp);
-close(fp);
+close(gd);
+close(fd);
 }
 
 usage(s)
