@@ -1,6 +1,6 @@
 /*  double/dbumount.c	umount device/file from DouBle device 1 Jan 1994
  *
- *  Copyright (C) 1994 Jean-Marc Verbavatz  <jmv@receptor.mgh.harvard.edu>
+ *  Copyright (C) 1994 Jean-Marc Verbavatz  <verbavatz@dsvidf.cea.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,16 +28,15 @@ main(argc, argv)
 int argc;
 char **argv;
 {
-int fp;
+int fd;
 
-if(argc != 2 || (fp = open(argv[1], O_RDWR))<0) {
+if(argc != 2 || (fd = open(argv[1], O_RDWR))<0) {
 	if(errno) perror(argv[0]);
 	usage(argv[0]);
 }
-
-if(ioctl(fp, DBLE_CLR_FD))
+if(ioctl(fd, DBLE_CLR_FD))
 	if(errno) perror(argv[0]);
-close(fp);
+close(fd);
 }
 
 usage(s)
